*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Change Colours of Boxplot  *;
* Purpose:     Hands-On GTL - Part A      *;
*              SAS Global Forum 2017      *;
*	           794                        *;
*-----------------------------------------*;

* Setting up paths;
%macro start;
  %let a=%sysget(SAS_EXECFILEPATH);
  %let b=%sysget(SAS_EXECFILENAME);

  %global path;
  %let path= %sysfunc(tranwrd(&a,%str(exercises\)&b,%str(startup\setup.sas)));
  %put &path;
%mend;
%start;

%include "&path";
libname source "&inpath";

proc format;
  value trtfmt 0 = "Placebo"
              54 = "Xanomeline Low Dose"
			  81 = "Xanomeline High Dose";
run;

*---------------------------------------------------------------*;
*					    Datasets								*;	
*---------------------------------------------------------------*;

* ADLBC;
data adlbc_all;
  set source.adlbc;
run;

* Changing colours by group order;
proc template;
  define statgraph boxplot_template;
    begingraph / datacolors = (green red yellow);
	  layout overlay;
	    boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
	  endlayout;
	endgraph;
  end;
run;

proc sort data = adlbc_all;
  by param;
run;

ods listing gpath = "&outpath";
ods graphics / reset = all imagename = "boxplot_colour_order1";

proc sgrender data = adlbc_all template = boxplot_template;
  by param;
  where param in ("Creatinine (umol/L)");
  format trtan trtfmt.;
run;


* Changing colours by group order - Including Markers;

proc template;
  define statgraph boxplot_template2;
    begingraph / datacolors = (green red yellow) datacontrastcolors = (darkgreen darkred darkyellow);
	  layout overlay;
	    boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
	  endlayout;
	endgraph;
  end;
run;

proc sort data = adlbc_all;
  by param;
run;

ods graphics / reset = all imagename = "boxplot_colour_order2";

proc sgrender data = adlbc_all template = boxplot_template2;
  by param;
  where param in ("Creatinine (umol/L)");
  format trtan trtfmt.;
run;


ods graphics / reset = all;
goptions reset = all;


* Changing colours by group order - Including Markers - Using SAS default color [Added on 18MAR2016];

proc template;
  define statgraph boxplot_template2;
    begingraph / datacolors = (graphdata3:color graphdata2:color graphdata1:color) datacontrastcolors = (graphdata3:contrastcolor graphdata2:contrastcolor graphdata1:contrastcolor);
	  layout overlay;
	    boxplot x = trtan y = aval / group = trtan groupdisplay = cluster;
	  endlayout;
	endgraph;
  end;
run;

proc sort data = adlbc_all;
  by param;
run;

ods graphics / reset = all imagename = "boxplot_colour_order3";

proc sgrender data = adlbc_all template = boxplot_template2;
  by param;
  where param in ("Creatinine (umol/L)");
  format trtan trtfmt.;
run;


ods graphics / reset = all;
goptions reset = all;
