*-----------------------------------------*;  
* Author:      Kriss Harris               *;
* Email:       ITALJET125@YAHOO.COM       *;
* Description: Using Attribute Maps       *;
* Purpose:     Hands-On GTL - Part A      *;
*              SAS Global Forum 2017      *;
*	           794                        *;
*-----------------------------------------*;

* Setting up paths;
%macro start;
  %let a=%sysget(SAS_EXECFILEPATH);
  %let b=%sysget(SAS_EXECFILENAME);

  %global path;
  %let path= %sysfunc(tranwrd(&a,%str(exercises\)&b,%str(startup\setup.sas)));
  %put &path;
%mend;
%start;

%include "&path";
libname source "&inpath";

proc format;
  value trtfmt 0 = "Placebo"
              54 = "Xanomeline Low Dose"
			  81 = "Xanomeline High Dose";
run;

*---------------------------------------------------------------*;
*					    Datasets								*;	
*---------------------------------------------------------------*;

* ADLBC;
data adlbc_all;
  set source.adlbc;
run;

* Specifying colours using attribute maps;

proc template;
  define statgraph boxplot_template_am;
    begingraph;

	/* Define the attribute map and assign the name "attributes" (Comments taken from SAS Help)*/
      discreteattrmap name="attributes" /discretelegendentrypolicy=attrmap;
        value "Placebo" / fillattrs=(color=green)  markerattrs=(color=darkgreen) lineattrs=(color=darkgreen); *lineattrs is needed for the whiskers;
        value "Xanomeline Low Dose" / fillattrs=(color=red) markerattrs=(color=darkred) lineattrs=(color=darkred); 
        value "Xanomeline High Dose" /fillattrs=(color=yellow)  markerattrs=(color=darkyellow) lineattrs=(color=darkyellow); 
      enddiscreteattrmap;

      /* Create attribute map variable GROUPATTRIBUTES to associate attribute
         map ATTRIBUTES with Treatment Group (Comments taken from SAS Help)*/
      discreteattrvar attrvar=groupattributes var=trtan attrmap="attributes";

	  layout overlay;
	    boxplot x = trtan y = aval / group = groupattributes groupdisplay = cluster;
	  endlayout;
	endgraph;
  end;
run;

proc sort data = adlbc_all;
  by param;
run;

ods listing gpath = "&outpath"; * Added outpath on 20APR2016;
ods graphics / reset = all imagename = "boxplot_attributemap";

proc sgrender data = adlbc_all template = boxplot_template_am;
  by param;
  where param in ("Creatinine (umol/L)");
  format trtan trtfmt.;
run;

ods graphics / reset = all;
goptions reset = all;
